@@ -145,9 +145,12 @@ And finally execute your task:
 from .app import AppContextTask, RequestContextTask, create_celery_app
 from .ext import FlaskCeleryExt
 
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 
 __all__ = (
-    '__version__', 'AppContextTask', 'RequestContextTask', 'create_celery_app',
-    'FlaskCeleryExt',
+    "__version__",
+    "AppContextTask",
+    "RequestContextTask",
+    "create_celery_app",
+    "FlaskCeleryExt",
 )
