@@ -16,21 +16,21 @@ from celery import Celery
 from celery.utils.log import get_task_logger
 from flask import Flask, current_app, request
 
-from flask_celeryext import AppContextTask, RequestContextTask, \
-    create_celery_app
+from flask_celeryext import AppContextTask, RequestContextTask, create_celery_app
 from flask_celeryext._mapping import FLASK_TO_CELERY_MAPPING
 from flask_celeryext.app import map_invenio_to_celery
 
 
 class celery_conf:
     """Configuration for testing Celery tasks for Celery >= 5.1.0."""
+
     CELERY_TASK_ALWAYS_EAGER = True
     CELERY_TASK_EAGER_PROPAGATES = True
-    CELERY_BROKER_URL = 'redis://localhost:6379/0'
-    CELERY_RESULT_BACKEND = 'redis://localhost:6379/1'
-    CELERY_ACCEPT_CONTENT = ['json', 'msgpack', 'yaml']
-    CELERY_RESULT_SERIALIZER = 'msgpack'
-    CELERY_TASK_SERIALIZER = 'msgpack'
+    CELERY_BROKER_URL = "redis://localhost:6379/0"
+    CELERY_RESULT_BACKEND = "redis://localhost:6379/1"
+    CELERY_ACCEPT_CONTENT = ["json", "msgpack", "yaml"]
+    CELERY_RESULT_SERIALIZER = "msgpack"
+    CELERY_TASK_SERIALIZER = "msgpack"
 
 
 def test_mapping():
@@ -38,25 +38,25 @@ def test_mapping():
     variables.
     """
     config = {
-        'CELERY_BROKER_URL': 'redis://localhost:6379/0',
-        'CELERY_RESULT_BACKEND': 'redis://localhost:6379/1',
-        'CELERY_ACCEPT_CONTENT': ['json', 'msgpack', 'yaml'],
-        'CELERY_RESULT_SERIALIZER': 'msgpack',
-        'CELERY_TASK_SERIALIZER': 'msgpack'
+        "CELERY_BROKER_URL": "redis://localhost:6379/0",
+        "CELERY_RESULT_BACKEND": "redis://localhost:6379/1",
+        "CELERY_ACCEPT_CONTENT": ["json", "msgpack", "yaml"],
+        "CELERY_RESULT_SERIALIZER": "msgpack",
+        "CELERY_TASK_SERIALIZER": "msgpack",
     }
 
     mapped = map_invenio_to_celery(config, FLASK_TO_CELERY_MAPPING)
-    assert mapped['broker_url'] == 'redis://localhost:6379/0'
-    assert mapped['result_backend'] == 'redis://localhost:6379/1'
-    assert mapped['accept_content'] == ['json', 'msgpack', 'yaml']
-    assert mapped['result_serializer'] == 'msgpack'
-    assert mapped['task_serializer'] == 'msgpack'
+    assert mapped["broker_url"] == "redis://localhost:6379/0"
+    assert mapped["result_backend"] == "redis://localhost:6379/1"
+    assert mapped["accept_content"] == ["json", "msgpack", "yaml"]
+    assert mapped["result_serializer"] == "msgpack"
+    assert mapped["task_serializer"] == "msgpack"
 
 
 def test_factory():
     """Test of factory method."""
     # Set the current Celery application
-    c = Celery('mycurrent')
+    c = Celery("mycurrent")
     c.set_current()
 
     app = Flask("testapp")
@@ -71,7 +71,7 @@ def test_appctx_task():
     app.config.from_object(celery_conf)
 
     # Set the current Celery application
-    c = Celery('mycurrent')
+    c = Celery("mycurrent")
     c.set_current()
 
     celery = create_celery_app(app)
@@ -114,7 +114,7 @@ def test_task_logger_propagation():
     @celery.task()
     def logtask():
         logger = get_task_logger(__name__)
-        while getattr(logger, 'parent', None):
+        while getattr(logger, "parent", None):
             assert logger.propagate == 1
             logger = logger.parent
 
@@ -125,12 +125,12 @@ def test_subtask_and_eager_dont_create_new_app_context(mocker):
     app = Flask("testapp")
     app.config.from_object(celery_conf)
     # Set the current Celery application
-    c = Celery('mycurrent')
+    c = Celery("mycurrent")
     c.set_current()
 
     celery = create_celery_app(app)
 
-    spy = mocker.spy(app, 'app_context')
+    spy = mocker.spy(app, "app_context")
 
     @celery.task
     def subtask():
